@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.94 date 2004-06-07
+ * version 0.95 date 2004-09-30
  * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -628,7 +628,7 @@ void cmd_stream_list( char * p_params, st_out_info * p_out_info )
 typedef struct s_cmd_tab
 {
   char * name; //command name
-  char * shortname; //short commadn name
+  char * shortname; //short command name
   char * params; //parameter format or NULL
   char * descr; //short description
   void (* func)( char * p_params, st_out_info * p_out_info ); //function to call
