@@ -1,5 +1,5 @@
 /* BLINKENLIGHTS PROXY
- * version 0.94 date 2004-06-07
+ * version 0.95 date 2004-09-30
  * Copyright (C) 2003-2004 1stein <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  */
@@ -21,13 +21,13 @@ st_outport_list * p_global_outport_list; //(extern)
 
 //number of milliseconds since start of the program (wraps around!)
 unsigned long global_millisecs; //(extern)
+//reference time to calculate number od milliseconds
+struct timeval global_millisecs_tv;
 
 //initialize global stuff
 //returns 0 on success, a negative value on error
 int global_init( st_out_info * p_out_info )
 {
-  struct timeval current_time;
-
   //create input port list
   p_global_inport_list = inport_new( p_out_info );
   if( p_global_inport_list == NULL )
@@ -46,9 +46,8 @@ int global_init( st_out_info * p_out_info )
   }
 
   //initialize milliseconds since start of the program
-  gettimeofday( &current_time, NULL );
-  global_millisecs = (unsigned long)current_time.tv_sec * 1000
-                   + (unsigned long)current_time.tv_usec % 1000;
+  global_millisecs = 0;
+  gettimeofday( &global_millisecs_tv, NULL );
 
   return 0;
 }
@@ -67,9 +66,12 @@ void global_exit( )
 void global_tick( )
 {
   struct timeval current_time;
+  long ms;
 
   //update number of milliseconds since start of the program
   gettimeofday( &current_time, NULL );
-  global_millisecs = (unsigned long)current_time.tv_sec * 1000
-                   + (unsigned long)current_time.tv_usec / 1000;
+  ms = (current_time.tv_sec - global_millisecs_tv.tv_sec) * 1000 //get number of ms since last call
+     + (current_time.tv_usec - global_millisecs_tv.tv_usec) / 1000;
+  global_millisecs += ms; //update global ms
+  global_millisecs_tv = current_time; //remember time of last call
 }
